@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,11 +13,8 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from array import array
 
-from hypothesis.internal.compat import hbytes, hrange, int_to_bytes
 from hypothesis.internal.conjecture.utils import calc_label_from_name
 from hypothesis.internal.floats import float_to_int, int_to_float
 
@@ -42,7 +37,7 @@ float (there is some redundancy here, as 7 * 8 = 56, which is larger than the
 largest integer that floating point numbers can represent exactly, so multiple
 encodings may map to the same float).
 
-If the tag bit is 1, we instead use somemthing that is closer to the normal
+If the tag bit is 1, we instead use something that is closer to the normal
 representation of floats (and can represent every non-negative float exactly)
 but has a better ordering:
 
@@ -104,7 +99,7 @@ def exponent_key(e):
         return unbiased
 
 
-ENCODING_TABLE = array("H", sorted(hrange(MAX_EXPONENT + 1), key=exponent_key))
+ENCODING_TABLE = array("H", sorted(range(MAX_EXPONENT + 1), key=exponent_key))
 DECODING_TABLE = array("H", [0]) * len(ENCODING_TABLE)
 
 for i, b in enumerate(ENCODING_TABLE):
@@ -246,6 +241,6 @@ def draw_float(data):
 
 
 def write_float(data, f):
-    data.write(int_to_bytes(float_to_lex(abs(f)), 8))
+    data.draw_bits(64, forced=float_to_lex(abs(f)))
     sign = float_to_int(f) >> 63
-    data.write(hbytes([sign]))
+    data.draw_bits(1, forced=sign)
