@@ -95,6 +95,9 @@ class IntList:
     def __delitem__(self, i):
         del self.__underlying[i]
 
+    def insert(self, i, v):
+        self.__underlying.insert(i, v)
+
     def __iter__(self):
         return iter(self.__underlying)
 
@@ -271,3 +274,11 @@ def find_integer(f):
         else:
             hi = mid
     return lo
+
+
+def pop_random(random, seq):
+    """Remove and return a random element of seq. This runs in O(1) but leaves
+    the sequence in an arbitrary order."""
+    i = random.randrange(0, len(seq))
+    swap(seq, i, len(seq) - 1)
+    return seq.pop()
