@@ -28,7 +28,7 @@ import typing
 import uuid
 from types import FunctionType
 
-import hypothesis.strategies as st
+from hypothesis import strategies as st
 from hypothesis.errors import InvalidArgument, ResolutionFailed
 from hypothesis.internal.compat import ForwardRef, typing_root_type
 from hypothesis.strategies._internal.ipaddress import (
@@ -331,7 +331,8 @@ if sys.version_info[:2] >= (3, 9):  # pragma: no cover
 
 try:  # pragma: no cover
     import numpy as np
-    from hypothesis.extra.numpy import arrays, array_shapes, scalar_dtypes, array_dtypes
+
+    from hypothesis.extra.numpy import array_dtypes, array_shapes, arrays, scalar_dtypes
 
     _global_type_lookup[np.dtype] = array_dtypes()
     _global_type_lookup[np.ndarray] = arrays(scalar_dtypes(), array_shapes(max_dims=2))
